@@ -1,8 +1,8 @@
 """Create the Convex Hull of a Mesh or a set of input points"""
 from vedo import *
 
-settings.defaultFont = 'Bongas'
-settings.useDepthPeeling = True
+settings.default_font = 'Bongas'
+settings.use_depth_peeling = True
 
 spid = Mesh(dataurl+"spider.ply").c("brown")
 
