@@ -5,19 +5,19 @@ Red lines join the center of the sphere to the surface point.
 Blue points are the N points used for fitting"""
 from vedo import *
 
-settings.defaultFont = 'Kanopus'
-settings.useDepthPeeling = True
+settings.default_font = 'Kanopus'
+settings.use_depth_peeling = True
 
 plt = Plotter()
 
-# load mesh and increase by a lot (N=2) the nr of surface vertices
-cow = Mesh(dataurl+"cow.vtk").alpha(0.3).subdivide(N=2)
+# load mesh and increase by a lot subdivide(2) the nr of surface vertices
+cow = Mesh(dataurl+"cow.vtk").alpha(0.3).subdivide(2)
 
 for i, p in enumerate(cow.points()):
     if i % 1000:
         continue  # skip most points
-    pts = cow.closestPoint(p, N=16)  # find the N closest points to p
-    sph = fitSphere(pts).alpha(0.05)  # find the fitting sphere
+    pts = cow.closest_point(p, n=16)   # find the n-closest points to p
+    sph = fit_sphere(pts).alpha(0.05)  # find the fitting sphere
     if sph is None:
         continue  # may fail if all points sit on a plane
     plt += sph
