@@ -22,11 +22,11 @@ desc = 3*sin(4*y)
 itr = Rbf(x, y, z, desc)          # Radial Basis Function interpolator
 #itr = Near(ptsubset, desc)       # Nearest-neighbour interpolator
 
-# interpolate desciptor on the full set of mesh vertices
+# interpolate descriptor on the full set of mesh vertices
 xi, yi, zi = np.split(pts, 3, axis=1)
 interpolated_desc = itr(xi, yi, zi)
 
-mesh.cmap('rainbow', interpolated_desc).addScalarBar(title='3sin(4y)')
+mesh.cmap('rainbow', interpolated_desc).add_scalarbar(title='3sin(4y)')
 rpts = Points(ptsubset, r=8, c='white')
 
 show(mesh, rpts, __doc__, axes=1).close()
