@@ -20,13 +20,13 @@ plt = Plotter(N=N, axes=1)
 plt.at(0).show(pts, __doc__)
 
 for i in range(1, N):
-    pts = pts.clone().smoothMLS1D(f=0.4).color(i)
+    pts = pts.clone().smooth_mls_1d(f=0.4).color(i)
 
     if i == N-1:
         # at the last iteration make sure points
         # are separated by tol (in % of bbox)
         pts.subsample(0.02)
 
-    plt.at(i).show(pts, f"Iteration {i}, #points: {pts.N()}")
+    plt.at(i).show(pts, f"Iteration {i}, #points: {pts.npoints}")
 
 plt.interactive().close()
