@@ -4,21 +4,18 @@
 from vedo import *
 
 
-plt1 = Plotter(title='Window 1', sharecam=False, shape=(8,2))
-plt2 = Plotter(title='Window 2', size=(700,700), pos=(400,0))
-
 ####################################################################################
 def keyfunc(evt):
-    printc('keyfunc called, pressed key:', evt.keyPressed)
+    printc('keyfunc called, pressed key:', evt.keypress)
 
-    if evt.keyPressed=='c':
+    if evt.keypress=='c':
         i = plt1.renderers.index(plt1.renderer)
         if i>= len(shapes): return
         shapes[i].color('red')
         plt1.render()
         plt2.render()
         onLeftClick(None)
-    elif evt.keyPressed=='h':
+    elif evt.keypress=='h':
         plt2.add(Text2D(instr, pos='bottom-right', c='dg', bg='g', font='Quikhand'))
 
 ####################################################################################
@@ -32,22 +29,26 @@ def onLeftClick(evt):
     ishape = shapes[i]
     sname = Text2D('This is called: '+ishape.name,
                    pos='top-center', c='r', bg='y', font='Calco')
-    sprop = Text2D('color = '+getColorName(ishape.color()),
+    sprop = Text2D('color = '+get_color_name(ishape.color()),
                    pos='bottom-left', c=ishape.color(), bg='k', font='Calco')
     instt = Text2D(instr, pos='bottom-right', c='dg', bg='g', font='Quikhand')
 
-    axes = ishape.buildAxes(yzGrid=False)
+    axes = Axes(ishape, yzgrid=False)
     acts = [ishape, axes, sname, sprop, instt]
 
     plt1.background('silver').render()
     plt2.clear()
     plt2.add(acts, resetcam=True)
 
+
 ####################################################################################
-plt1.addCallback("KeyPress", keyfunc)
-plt1.addCallback("LeftButtonPress", onLeftClick)
+plt1 = Plotter(title='Window 1', sharecam=False, shape=(8,2))
+plt2 = Plotter(title='Window 2', size=(700,700), pos=(400,0))
+
+plt1.add_callback("KeyPress", keyfunc)
+plt1.add_callback("LeftButtonPress", onLeftClick)
 plt1.at(len(plt1.renderers)-1).show(
-    Picture(dataurl+'images/embl_logo.jpg').rotateX(-20),
+    Picture(dataurl+'images/embl_logo.jpg').rotate_x(-20),
     Text2D('Some footnote', pos='bottom-right', font='Quikhand', c='grey', s=0.6),
 )
 
@@ -60,8 +61,8 @@ for i in range(15):
 
 ####################################################################################
 instr  = "Click on the left panel to select a shape\n"
-instr += "Press c to make the shape red\n"
-plt2.addCallback('KeyPress', keyfunc)
+instr += "Press c to make the shape red"
+plt2.add_callback('KeyPress', keyfunc)
 plt2.show(
     __doc__,
     VedoLogo(distance=10),
