@@ -1,9 +1,9 @@
 from vedo import settings, Plotter, ParametricShape, VedoLogo, Text2D
 
-settings.rendererFrameWidth = 1
+settings.renderer_frame_width = 1
 
 ##############################################################################
-def onLeftClick(evt):
+def on_left_click(evt):
     if not evt.actor: return
     shapename.text(f'This is called: {evt.actor.name}, on renderer nr.{evt.at}')
     plt.at(1).remove(actsonshow).add(evt.actor, resetcam=True)
@@ -13,7 +13,7 @@ def onLeftClick(evt):
 ##############################################################################
 sy, sx, dx = 0.12, 0.12, 0.01
 # Define the renderers rectangle areas
-# to help finding bottomleft&topright corners check out utils.gridcorners()
+# to help finding bottomleft&topright corners check out utils.grid_corners()
 shape = [
     dict(bottomleft=(0,0), topright=(1,1), bg='k7'), # the full empty window
     dict(bottomleft=(dx*2+sx,0.01), topright=(1-dx,1-dx), bg='w'), # the display window
@@ -27,7 +27,7 @@ shape = [
 ]
 
 plt = Plotter(shape=shape, sharecam=False, size=(1050, 980))
-plt.addCallback("when i click my mouse button please call", onLeftClick)
+plt.add_callback("when i click my mouse button please call", on_left_click)
 
 for i in range(2,9):
     ps = ParametricShape(i).color(i)
