@@ -1,7 +1,7 @@
 """Boolean operations with Meshes"""
 from vedo import *
 
-settings.useDepthPeeling = True
+settings.use_depth_peeling = True
 
 # declare the instance of the class
 plt = Plotter(shape=(2, 2), interactive=False, axes=3)
@@ -18,7 +18,7 @@ plt.at(1).show(b1, "intersect", resetcam=False)
 b2 = s1.boolean("plus", s2).c("blue").wireframe(True)
 plt.at(2).show(b2, "plus", resetcam=False)
 
-b3 = s1.boolean("minus", s2).computeNormals().addScalarBar(c='white')
+b3 = s1.boolean("minus", s2).compute_normals().add_scalarbar(c='white')
 plt.at(3).show(b3, "minus", resetcam=False)
 
 plt.interactive().close()
