@@ -5,5 +5,5 @@ from vedo import *
 s = Mesh(dataurl+'cow.vtk')
 
 plt = show(s, __doc__, bg='black', bg2='bb', interactive=False)
-plt.addCutterTool(s, mode='sphere') #modes= sphere, plane, box
+plt.add_cutter_tool(s, mode='sphere') #modes= sphere, plane, box
 plt.close()
\ No newline at end of file
