@@ -9,7 +9,7 @@ from vedo import dataurl, printc, Plotter, Point, Mesh
 def myfnc(evt):
     mesh = evt.actor
     # printc('dump event info', evt)
-    if not mesh or evt.keyPressed != "c":
+    if not mesh or evt.keypress != "c":
         printc("click mesh and press c", c="r")
         return
     printc("point:", mesh.picked3d, c="v")
@@ -20,5 +20,5 @@ def myfnc(evt):
 plt = Plotter(axes=1)
 plt += Mesh(dataurl+"bunny.obj").color("gold")
 plt += __doc__
-plt.addCallback('KeyPress', myfnc)
+plt.add_callback('KeyPress', myfnc)
 plt.show().close()
