@@ -5,8 +5,8 @@ def func(event):  # callback function
     p = event.picked3d
     if p is None:
         return
-    pts = Points(msh.closestPoint(p, N=50), r=6)
-    sph = fitSphere(pts).alpha(0.1)
+    pts = Points(msh.closest_point(p, n=50), r=6)
+    sph = fit_sphere(pts).alpha(0.1)
     pts.name = "mypoints"   # we give it a name to make it easy to
     sph.name = "mysphere"   # remove the old and add the new ones
     txt.text(f'Radius : {sph.radius}\nResidue: {sph.residue}')
@@ -15,10 +15,10 @@ def func(event):  # callback function
 txt = Text2D(__doc__, bg='yellow', font='Calco')
 
 msh = Mesh(dataurl+'290.vtk').subdivide()
-msh.addCurvatureScalars(method=2)
-msh.cmap('PRGn', vmin=-0.02).addScalarBar()
+msh.compute_curvature(method=2)
+msh.cmap('PRGn', vmin=-0.02).add_scalarbar()
 
 plt = Plotter(axes=1)
-plt.addCallback('mouse hover', func)
+plt.add_callback('mouse hover', func)
 plt.show(msh, txt, viewup='z')
 plt.close()
