@@ -2,15 +2,15 @@
 (hover mouse to place the points)"""
 from vedo import *
 
-settings.defaultFont = "Ubuntu"
-settings.useDepthPeeling = True
+settings.default_font = "Ubuntu"
+settings.use_depth_peeling = True
 
 
 def func(evt):                 # this is the callback function
     i = evt.at                 # the renderer nr. which is being hit
     pt2d = evt.picked2d        # 2D screen coordinate
     # passing a list of meshes will force the points to be placed on any of them
-    pt3d = plt.at(i).computeWorldPosition(pt2d, objs=[objs[i]])
+    pt3d = plt.at(i).compute_world_position(pt2d, objs=[objs[i]])
     if mag(pt3d) < 0.01:
         return
     newpt = Point(pt3d).color(i)
@@ -29,7 +29,7 @@ mesh2.c('indigo1').lc('grey9').lw(0.1)
 objs = [mesh1, mesh2]
 
 plt = Plotter(N=2, bg='blackboard', axes=1, sharecam=False)
-plt.addCallback('mouse move', func)
+plt.add_callback('mouse move', func)
 
 plt.at(0).show(mesh1, __doc__, viewup='z')
 plt.at(1).show(mesh2, txt, zoom=1.4)
