@@ -1,7 +1,7 @@
 from vedo import *
 
-m1 = Mesh(dataurl+'bunny.obj').c('g').normalize().rotateX(+90)
-m2 = Mesh(dataurl+'teddy.vtk').c('v').normalize().rotateZ(-90).pos(3,0,0)
+m1 = Mesh(dataurl+'bunny.obj').c('g').normalize().rotate_x(+90)
+m2 = Mesh(dataurl+'teddy.vtk').c('v').normalize().rotate_z(-90).pos(3,0,0)
 
 plt = show(m1, m2, axes=1)
 
