@@ -12,14 +12,14 @@ import pymeshfix
 import tetgen
 import vedo
 
-vedo.settings.useDepthPeeling = True
+vedo.settings.use_depth_peeling = True
 
 amesh = vedo.Mesh(vedo.dataurl+'290.vtk')
 
 # repairing also closes the mesh in a nice way
 meshfix = pymeshfix.MeshFix(amesh.points(), amesh.faces())
 meshfix.repair()
-repaired = vedo.Mesh(meshfix.mesh).lineWidth(1).alpha(0.5)
+repaired = vedo.Mesh(meshfix.mesh).linewidth(1).alpha(0.5)
 
 # tetralize the closed surface
 tet = tetgen.TetGen(repaired.points(), repaired.faces())
