@@ -4,7 +4,7 @@
 import vedo
 import polyscope
 
-m = vedo.load(vedo.dataurl+'embryo.tif').isosurface().extractLargestRegion()
+m = vedo.load(vedo.dataurl+'embryo.tif').isosurface().extract_largest_region()
 # m = vedo.load(vedo.dataurl+'man.vtk')
 
 polyscope.set_program_name("vedo using polyscope")
@@ -20,4 +20,4 @@ ps_mesh.add_scalar_quantity("heights", m.points()[:,2], defined_on='vertices')
 ps_mesh.set_material("wax") # wax, mud, jade, candy
 polyscope.show()
 
-vedo.show(m, axes=11)
\ No newline at end of file
+vedo.show(m, axes=11)
