@@ -3,7 +3,8 @@ from scipy.optimize import curve_fit
 from vedo import np, settings, Marker
 from vedo.pyplot import plot
 
-settings.defaultFont = 'Calco'
+settings.default_font = 'Calco'
+settings.remember_last_figure_format = True
 
 xdata = [230, 234, 240, 243, 246, 249, 252]
 ydata = [0,   0,    11,  62,  15,  21, 100]
@@ -37,11 +38,11 @@ fig = plot(
     label='data',
 )
 
-fig += plot(x, y, lw=5, like=fig, label='fit')
+fig += plot(x, y, lw=5, label='fit')
 fig += Marker('*', s=0.5, c='r4').pos(x0,y0, 0.1)
 
-fig.addLabel('\mu', marker='*', mc="r4")
-fig.addLegend("top-left", vspace=2.5)
+fig.add_label('\mu', marker='*', mc="r4")
+fig.add_legend("top-left", vspace=2.5)
 
 fig.show(size=(900, 650), zoom='tight').close()
 
