@@ -1,6 +1,9 @@
 """Superimpose and compare histograms"""
 import numpy as np
 from vedo.pyplot import histogram
+from vedo import settings
+
+settings.remember_last_figure_format = True
 
 np.random.seed(0)
 theory = np.random.randn(500).tolist()
@@ -21,13 +24,13 @@ fig = histogram(
 
 # Extract the 11th bin and color it purple
 fig.unpack(10).c('purple4')
-fig.addLabel("special bin", marker='s', mc='purple4')
+fig.add_label("special bin", marker='s', mc='purple4')
 
-# Add a second histogram, format it like histo, so it can be superimposed
-fig += histogram(backgr, like=fig, label='background')
+# Add a second histogram to be superimposed
+fig += histogram(backgr, label='background')
 
 # Add the data histogram with poissonian errors
-fig += histogram(data, like=fig, marker='o', errors=True, fill=False, label='data')
+fig += histogram(data, marker='o', errors=True, fill=False, label='data')
 
-fig.addLegend(s=0.8)
+fig.add_legend(s=0.8)
 fig.show(zoom='tight').close()
