@@ -3,7 +3,8 @@ import numpy as np
 from vedo.pyplot import histogram, plot
 from vedo import settings
 
-settings.defaultFont = "Bongas"
+settings.default_font = "Bongas"
+settings.remember_last_figure_format = True
 
 mu, sigma, n, bins = 100.0, 15.0, 600, 50
 samples = np.random.normal(loc=mu, scale=sigma, size=n)
@@ -21,9 +22,9 @@ fig = histogram(
     label="gaussian",
 )
 
-fig += plot(x, y, "-", lc='orange5', like=fig, label="some fit")
-fig += plot(x, y*(1+dy), "--", lc='orange5', lw=2, like=fig)
-fig += plot(x, y*(1-dy), "--", lc='orange5', lw=2, like=fig)
+fig += plot(x, y, "-", lc='orange5', label="some fit")
+fig += plot(x, y*(1+dy), "--", c='orange5', lw=2)
+fig += plot(x, y*(1-dy), "--", c='orange5', lw=2)
 
-fig.addLegend()
+fig.add_legend()
 fig.show(size=(800,700), zoom="tight").close()
