@@ -16,11 +16,11 @@ radhisto = histogram(
 show(radhisto, at=0, N=2, axes=0, sharecam=False)
 
 ##################################################################
-hyp = Hyperboloid(res=20).cutWithPlane().rotateY(-90)
+hyp = Hyperboloid(res=20).cut_with_plane().rotate_y(-90)
 hyp.color('grey').alpha(0.3)
 
 # select 10 random indices of points on the surface
-idx = np.random.randint(0, hyp.NPoints(), size=10)
+idx = np.random.randint(0, hyp.npoints, size=10)
 
 radhistos = []
 for i in idx:
@@ -32,13 +32,13 @@ for i in idx:
          r1=0.2,     # inner radius
          phigap=1.0, # leave a space btw phi bars
          cmap='viridis_r',
-         showDisc=False,
-         showAngles=False,
-         showErrors=False,
+         show_disc=False,
+         show_angles=False,
+         show_errors=False,
     )
     rh.scale(0.15)          # scale histogram to make it small
     rh.pos(hyp.points(i))   # set its position on the surface
-    rh.orientation(hyp.normalAt(i)) # orient it along normal
+    rh.orientation(hyp.normal_at(i)) # orient it along normal
     radhistos.append(rh)
 
 show(hyp, radhistos, at=1).interactive().close()
