@@ -10,20 +10,20 @@ printc('Mesh point arrays:', mesh0.pointdata.keys())
 mesh0.cmap('terrain')
 
 isol = mesh0.isolines(n=10).color('w')
-isob = mesh0.isobands(n=5).addScalarBar(title="H=Elevation")
+isob = mesh0.isobands(n=5).add_scalarbar("H=Elevation")
 
 # make a copy and interpolate the Scalars from points to cells
-mesh1 = mesh0.clone(deep=False).mapPointsToCells()
+mesh1 = mesh0.clone(deep=False).map_points_to_cells()
 printc('Mesh cell arrays :', mesh1.celldata.keys())
 
 gvecs = mesh1.gradient(on='cells')
-cc = mesh1.cellCenters()
+cc = mesh1.cell_centers()
 ars = Arrows(cc, cc + gvecs*0.01, c='bone_r').lighting('off')
-ars.addScalarBar3D(title='|\nablaH|~\dot~0.01 [arb.units]')
+ars.add_scalarbar3d(title='|\nablaH|~\dot~0.01 [arb.units]')
 
 # colormap the gradient magnitude directly on the mesh
 mesh2 = mesh1.clone(deep=False).lw(0.1).cmap('jet', mag(gvecs), on='cells')
-mesh2.addScalarBar3D(title='|\nablaH| [arb.units]')
+mesh2.add_scalarbar3d(title='|\nablaH| [arb.units]')
 
 plt = Plotter(N=4, size=(1200,900), axes=11)
 plt.at(0).show(mesh0, isol, __doc__)
