@@ -1,13 +1,13 @@
 # A plot(mode="bars") example. Useful to plot categories.
-from vedo import precision, Text3D, colorMap, settings
+from vedo import precision, Text3D, color_map, settings
 from vedo.pyplot import plot
 
-settings.defaultFont = "Meson"
+settings.default_font = "Meson"
 
 counts  = [1946, 8993, 3042, 1190, 1477,    0,    0]
 percent = [11.68909178, 54.01850072, 18.27246516,  7.14800577,  8.87193657, 0, 0]
 labels  = ['<100', '100-250', '250-500', '500-750', '750-1000', '1000-2000', '>2000']
-colors  = colorMap(range(len(counts)), "hot")
+colors  = color_map(range(len(counts)), "hot")
 
 # plot() will return a PlotBars object
 fig = plot(
@@ -17,8 +17,8 @@ fig = plot(
     aspect=16/9,
     title='Clusters in lux range',
     axes=dict(
-        xLabelRotation=30,
-        xLabelSize=0.02,
+        xlabel_rotation=30,
+        xlabel_size=0.02,
     ),
 )
 
