@@ -2,7 +2,7 @@
 import numpy as np
 from vedo import *
 
-settings.useDepthPeeling = True
+settings.use_depth_peeling = True
 
 n = 3000
 p = np.random.normal(7, 0.3, (n,3))
@@ -14,7 +14,7 @@ pts = Points(p, alpha=0.5)
 vol = pts.density().c('Dark2').alpha([0.1,1]) # density() returns a Volume
 
 r = precision(vol.info['radius'], 2) # retrieve automatic radius value
-vol.addScalarBar3D(title='Density (counts in r_s ='+r+')', c='k', italic=1)
+vol.add_scalarbar3d(title='Density (counts in r_s ='+r+')', c='k', italic=1)
 
 show(pts, vol, __doc__, axes=True).close()
 
