@@ -3,8 +3,9 @@ Any 3D Mesh object can be added to the figure!"""
 from vedo import *
 from vedo.pyplot import plot, Figure
 
-settings.defaultFont = "Cartoons123"
+settings.default_font = "Cartoons123"
 settings.palette = 2
+settings.remember_last_figure_format = True
 
 # Create an empty Figure and plot on it
 fig = Figure(
@@ -14,14 +15,14 @@ fig = Figure(
     aspect=16/9,  # desired aspect ratio
     xtitle="speed [mph]",
     grid=True,
-    axes=dict(axesLineWidth=3, xyFrameLine=3),
+    axes=dict(axes_linewidth=3, xyframe_line=3),
 )
 
 for i in range(2,11,2):
     x = np.linspace(0, 4*np.pi, 20)
     y = np.sin(x) * np.sin(x/12) * i/5
 
-    fig += plot(x, y, '-0', lc=i, splined=True, like=fig)
+    fig += plot(x, y, '-0', c=i, splined=True)
 
 fig += Arrow([5,-1], [8,-1], s=0.5, c='green3')
 
