@@ -2,11 +2,11 @@
 from vedo import *
 import numpy as np
 
-settings.defaultFont = "Glasgo"
-settings.useParallelProjection = True
+settings.default_font = "Glasgo"
+settings.use_parallel_projection = True
 
 vals = np.abs(np.random.randn(4*6))  # pixel heights
-cols = colorMap(vals, "summer")
+cols = color_map(vals, "summer")
 
 k = 0
 items = [__doc__]
