@@ -3,13 +3,12 @@ Simulate interacting charged particles in 3D space.
 """
 # An example simulation of N particles scattering on a charged target.
 # See e.g. https://en.wikipedia.org/wiki/Rutherford_scattering
-# By Tommy Vandermolen, 3 August 2018
-from vedo import Plotter, Cube, Sphere, mag2, versor, vector, settings
+# By Tommy Vandermolen
 import numpy as np
+from vedo import Plotter, Cube, Sphere, mag2, versor, vector
 
 K_COULOMB = 8987551787.3681764  # N*m^2/C^2
 plt = None  # so that it can be also used without visualization
-settings.allow_interaction = True
 
 
 class ParticleSim:
@@ -62,7 +61,6 @@ class ParticleSim:
                 a.vsphere.pos(a.pos)
             if plt:
                 plt.show(resetcam=not i, azimuth=1)
-                if plt.escaped: break # if ESC is hit during the loop
 
 
 class Particle:
@@ -99,7 +97,7 @@ if __name__ == "__main__":
 
     plt += Cube().c('w').wireframe(True).lighting('off') # a wireframe cube
 
-    sim = ParticleSim(dt=1e-5, iterations=100)
+    sim = ParticleSim(dt=1e-5, iterations=60)
     sim.add_particle((-0.4, 0, 0), color="w", charge=3e-6, radius=0.01, fixed=True)  # the target
 
     positions = np.random.randn(500, 3) / 60  # generate a beam of particles
@@ -108,4 +106,4 @@ if __name__ == "__main__":
         sim.add_particle(p, charge=0.01e-6, mass=0.1e-6, vel=(1000, 0, 0), negligible=True)
 
     sim.simulate()
-    plt.show(interactive=True, resetcam=False).close()
+    plt.interactive().close()
