@@ -4,8 +4,6 @@ Press ESC to quit"""
 # https://www.youtube.com/watch?v=MtG9cueB548
 from vedo import *
 
-settings.allow_interaction = True
-
 # Load the solution:
 x1, y1, z1,  x2, y2, z2 = np.load(download(dataurl+'3Dpen.npy'))
 p1, p2 = np.c_[x1,y1,z1], np.c_[x2,y2,z2]
@@ -23,7 +21,8 @@ axes = Axes(xrange=(-3,3), yrange=(-3,3), zrange=(-3,3))
 plt = Plotter(interactive=False)
 plt.show(axes, __doc__, viewup='z')
 
-pb = ProgressBar(0, len(p1))
+pb = ProgressBar(0, 50)
+i = 0
 for b1, b2 in zip(p1,p2):
     ball1.pos(b1)
     ball2.pos(b2)
@@ -32,7 +31,8 @@ for b1, b2 in zip(p1,p2):
     # show at max frame rate of 15 Hz
     plt.show(ball1, ball2, rod1, rod2, resetcam=False, rate=15)
     pb.print()
-    if plt.escaped:  # if ESC is pressed
+    i+=1
+    if i > 50:
         break
 
-plt.interactive()
+plt.interactive().close()
