@@ -9,7 +9,7 @@ gpts = Points(pts, r=10).c('green',0.5)
 # Create a spline where the final points are more dense (easing)
 line = Spline(pts, easing="OutCubic", res=100)
 
-vpts = line.clone().pointSize(3).shift(0,0.1,0) # a dotted copy
+vpts = line.clone().point_size(3).shift(0,0.1,0) # a dotted copy
 
 # Calculate positions as a fraction of the length of the line,
 # being x=0 the first point and x=1 the last point.
@@ -20,7 +20,7 @@ equi_pts = Points([line.eval(x) for x in np.arange(0,1, 0.1)]).c('blue')
 redpt = Point(r=25).c('red')
 plt = show(vpts, gpts, line, redpt, equi_pts, axes=1, interactive=0)
 # Animation
-for i in range(line.N()):
+for i in range(line.npoints):
     x = line.points(i)
     redpt.pos(x) # assign the new position
     plt.render()
