@@ -1,14 +1,14 @@
 """Visualization of a discretized Earth model"""
 import vedo
 
-vedo.settings.defaultFont = 'Kanopus'
+vedo.settings.default_font = 'Kanopus'
 
 tet = vedo.TetMesh(vedo.dataurl+'earth_model.vtu')
 conductor = tet.clone().threshold('cell_scalars', above=0, below=4)
 
 # Crop the initial mesh
 box = vedo.Box(size=[503500, 505000, 6414000, 6417000, -1830, 600])
-tet.cutWithMesh(box, wholeCells=True)
+tet.cut_with_mesh(box, whole_cells=True)
 
 # We need to build a look up table for our color bar
 lut_table = [
@@ -26,20 +26,20 @@ lut_table = [
     (13.0, 'lime',       1, "Layer^E"),
     (15.0, 'seagreen',   1, "Layer^V"),
 ]
-lut = vedo.buildLUT(lut_table)
+lut = vedo.build_lut(lut_table)
 
 msh = tet.tomesh(shrink=0.95).cmap(lut, 'cell_scalars', on='cells')
-msh.addScalarBar3D(
-                categories=lut_table,
-                pos=(505500, 6416900, -630),
-                title='Units',
-                titleSize=1.25,
-                labelSize=1.5,
-                s=[100, 2200],
+msh.add_scalarbar3d(
+    categories=lut_table,
+    pos=(505500, 6416900, -630),
+    title='Units',
+    title_size=1.25,
+    label_size=1.5,
+    s=[100, 2200],
 )
 # put scalarbar vertical, tell camera to keep bounds into account
-msh.scalarbar.rotateX(90, around='itself').rotateZ(60, around='itself')
-msh.scalarbar.useBounds()
+msh.scalarbar.rotate_x(90, around='itself').rotate_z(60, around='itself')
+msh.scalarbar.use_bounds()
 
 # Create cmap for conductor
 cond = conductor.tomesh().cmap(lut, 'cell_scalars', on='cells')
@@ -49,20 +49,20 @@ axes = vedo.Axes(
     xtitle='Easting (m)',
     ytitle='Northing (m)',
     ztitle='Elevation (m)',
-    xTitlePosition=0.65,
-    yTitlePosition=0.65,
-    zTitlePosition=0.65,
-    yTitleOffset=-0.22,
-    zTitleOffset= 0.06,
-    yLabelRotation=90,
-    yLabelOffset=-1.5,
-    zAxisRotation=15,
-    axesLineWidth=3,
-    gridLineWidth=2,
-    yShiftAlongX=1,
-    tipSize=0,
-    yzGrid=True,
-    xyFrameLine=True,
+    xtitle_position=0.65,
+    ytitle_position=0.65,
+    ztitle_position=0.65,
+    ytitle_offset=-0.22,
+    ztitle_offset= 0.06,
+    ylabel_rotation=90,
+    ylabel_offset=-1.5,
+    zaxis_rotation=15,
+    axes_linewidth=3,
+    grid_linewidth=2,
+    yshift_along_x=1,
+    tip_size=0,
+    yzgrid=True,
+    xyframe_line=True,
 )
 
 vedo.show(msh, cond, axes, __doc__, size=(1305, 1020),
