@@ -4,7 +4,7 @@ over an ellipsoidal neighborhood"""
 from vedo import *
 
 embryo = Volume(dataurl+'embryo.tif')
-embryo.printHistogram(logscale=1)
+embryo.print_histogram(logscale=1)
 
 eroded = embryo.clone().erode(neighbours=(2,2,2))
 dilatd = eroded.clone().dilate(neighbours=(2,2,2))
