@@ -2,9 +2,9 @@ from vedo import Picture, show, settings
 from vedo.pyplot import histogram
 import numpy as np
 
-settings.defaultFont = "Theemim"
+settings.default_font = "Theemim"
 
-pic = Picture("https://aws1.discourse-cdn.com/business4/uploads/imagej/original/3X/5/8/58468da123203f6056ca786adf159064db47aefa.jpeg")
+pic = Picture("https://thumbs.dreamstime.com/z/green-grass-vase-tranquillity-white-rectangular-nature-81294508.jpg")
 msh = pic.tomesh()                # convert it to a quad-mesh
 rgb = msh.pointdata["RGBA"]       # numpy array
 
@@ -16,9 +16,9 @@ ids_r = np.where(ratio_r > 0.38)  # threshold to find the red vase
 ids_g = np.where(ratio_g > 0.36)  # threshold for grass
 ids_w = np.where(tot > 240*3)     # threshold to identify white areas
 
-data_g = np.zeros(msh.N())
-data_r = np.zeros(msh.N())
-data_w = np.zeros(msh.N())
+data_g = np.zeros(msh.npoints)
+data_r = np.zeros(msh.npoints)
+data_w = np.zeros(msh.npoints)
 data_r[ids_r] = 1.0
 data_g[ids_g] = 1.0
 data_w[ids_w] = 1.0
