@@ -1,12 +1,12 @@
 """Probe a voxel dataset at specified points
 and plot a histogram of the values"""
-from vedo import np, dataurl, Volume, Axes, probePoints, show
+from vedo import np, dataurl, Volume, Axes, probe_points, show
 from vedo.pyplot import histogram
 
 vol = Volume(dataurl+'embryo.slc').print()
 
 pts = np.random.rand(5000, 3)*256
-mpts = probePoints(vol, pts).pointSize(3)
+mpts = probe_points(vol, pts).point_size(3)
 
 mpts.print()
 # valid = mpts.pointdata['vtkValidPointMask']
