@@ -5,21 +5,20 @@ from vedo import dataurl, precision, Sphere, Volume, Plotter
 def func(evt):
     if not evt.actor:
         return
-    pid = evt.actor.closestPoint(evt.picked3d, returnPointId=True)
+    pid = evt.actor.closest_point(evt.picked3d, return_point_id=True)
     txt = f"Probing:\n{precision(evt.actor.picked3d, 3)}\nvalue = {arr[pid]}"
 
     sph = Sphere(evt.actor.points(pid), c='orange7').pickable(False)
-    vig = sph.vignette(txt, s=7, offset=(-150,15), font=2).followCamera()
-    vig.name = "Vignette"
+    fp = sph.flagpole(txt, s=7, offset=(-150,15), font=2).follow_camera()
     # remove old and add the two new objects
-    plt.remove('Sphere', 'Vignette').add(sph, vig)
+    plt.remove('Sphere', 'FlagPole').add(sph, fp)
 
 vol = Volume(dataurl+'embryo.slc').alpha([0,0,0.8]).c('w').pickable(False)
-vslice = vol.slicePlane(origin=vol.center(), normal=(0,1,1))
-vslice.cmap('Purples_r').lighting('off').addScalarBar(title='Slice', c='w')
+vslice = vol.slice_plane(origin=vol.center(), normal=(0,1,1))
+vslice.cmap('Purples_r').lighting('off').add_scalarbar('Slice', c='w')
 arr = vslice.pointdata[0] # retrieve vertex array data
 
 plt = Plotter(axes=9, bg='k', bg2='bb')
-plt.addCallback('as my mouse moves please call', func) # be kind to vedo ;)
+plt.add_callback('as my mouse moves please call', func) # be kind to vedo ;)
 plt.show(vol, vslice, __doc__)
 plt.close()
