@@ -14,10 +14,11 @@ plt = Slicer3DPlotter(
     bg="white",
     bg2="lightblue",
     cmaps=("gist_ncar_r", "jet", "Spectral_r", "hot_r", "bone_r"),
-    useSlider3D=False,
+    use_slider3d=False,
 )
 
 # Can now add any other object to the Plotter scene:
-# plt += Text2D('some message', font='arial')
+# plt += Text2D('some message')
+# plt.show().interactive()
 
 plt.close()
