@@ -2,24 +2,24 @@
 default ray casting."""
 from vedo import *
 
-# settings.useDepthPeeling = False
+# settings.use_depth_peeling = False
 
 tetm = TetMesh(dataurl+'limb_ugrid.vtk')
-tetm.color('jet').alphaUnit(100) # make the tets more transparent
-tetm.addScalarBar3D()
+tetm.color('jet').alpha_unit(100) # make the tets more transparent
+tetm.add_scalarbar3d()
 
 # Build a Mesh object made of all the boundary triangles
 wmesh = tetm.tomesh(fill=False).wireframe()
 
 # Make a copy of tetm and shrink the tets
-shrinked = tetm.clone().shrink(0.5)
+shrunk = tetm.clone().shrink(0.5)
 
 # Build a Mesh object and cut it
-cmesh = shrinked.tomesh(fill=True)
+cmesh = shrunk.tomesh(fill=True)
 
 show([(tetm, __doc__),
       (wmesh, "..wireframe surface"),
-      (cmesh, "..shrinked tetrahedra"),
+      (cmesh, "..shrunk tetrahedra"),
      ], N=3, axes=1,
 ).close()
 
