@@ -59,7 +59,12 @@ __website__    = "https://github.com/marcomusy/vedo"
 # mount_staging
 # rm ~/Projects/StagingServer/var/www/html/vtkplotter.embl.es/autodocs/html
 # mv html/ ~/Projects/StagingServer/var/www/html/vtkplotter.embl.es/autodocs/
-############## pdoc excludes
+#
+# To generate pdf
+# sudo apt install wkhtmltopdf
+# wkhtmltopdf --encoding utf8 -s A4 html/vedo/index.html 01_index.pdf
+
+########################################## pdoc excludes:
 # __pdoc__ = {}
 # __pdoc__['backends'] = False
 # __pdoc__['cli'] = False
@@ -168,17 +173,16 @@ vtk_version = (
     int(vtkVersion().GetVTKBuildVersion()),
 )
 
-if vtk_version[0] >= 9:
-    if "Windows" in sys_platform or "Linux" in sys_platform:
-        settings.use_depth_peeling = True
-
+# if vtk_version[0] >= 9:
+#     if "Windows" in sys_platform or "Linux" in sys_platform:
+#         settings.use_depth_peeling = True
 
 installdir = os.path.dirname(__file__)
 dataurl = "https://vedo.embl.es/examples/data/"
 
 plotter_instance = None
 notebook_plotter = None
-notebook_backend  = None
+notebook_backend = None
 
 ## fonts
 fonts_path = os.path.join(installdir, "fonts/")
@@ -231,4 +235,9 @@ logger.setLevel(logging.INFO)
 
 ################################################# silence annoying messages
 warnings.simplefilter(action="ignore", category=FutureWarning)
-np.warnings.filterwarnings('ignore', category=np.VisibleDeprecationWarning)
+try:
+    np.warnings.filterwarnings('ignore', category=np.VisibleDeprecationWarning)
+except AttributeError:
+    pass
+
+
