@@ -124,7 +124,9 @@ class _DataArrayHelper:
             data = self.actor.inputdata().GetFieldData()
         arrnames = []
         for i in range(data.GetNumberOfArrays()):
-            arrnames.append(data.GetArray(i).GetName())
+            name = data.GetArray(i).GetName()
+            if name:
+                arrnames.append(name)
         return arrnames
 
     def remove(self, key):
@@ -567,15 +569,12 @@ class Base3DProp:
                 l = Line(p-v, p+v).lw(3).c('red')
                 show(c1.wireframe().lw(3), l, c2, axes=1)
         """
-        # if self.transform:
-        #     tr = self.transform
-        # else:
-        #     T = self.GetMatrix()
-        #     tr = vtk.vtkTransform()
-        #     tr.SetMatrix(T)
-        # if invert:
-        #     tr = tr.GetInverse()
-        # return tr if self.transform:
+        if self.transform:
+            tr = self.transform
+            if invert:
+                tr = tr.GetInverse()
+            return tr
+
         T = self.GetMatrix()
         tr = vtk.vtkTransform()
         tr.SetMatrix(T)
@@ -1407,7 +1406,7 @@ class BaseActor(Base3DProp):
             if isinstance(self.scalarbar, vtk.vtkActor):
                 plt.renderer.RemoveActor(self.scalarbar)
             elif isinstance(self.scalarbar, vedo.Assembly):
-                for a in self.scalarbar.get_meshes():
+                for a in self.scalarbar.unpack():
                     plt.renderer.RemoveActor(a)
         if c is None:
             c = "gray"
@@ -1667,7 +1666,7 @@ class BaseGrid(BaseActor):
         vmax : float
             force the max of the scalar range to be this value
         """
-        # superseeds method in Points, Mesh
+        # supersedes method in Points, Mesh
         if vmin is None:
             vmin, _ = self._data.GetScalarRange()
         if vmax is None:
