@@ -33,7 +33,7 @@ __all__ = [
 
 
 try:
-    import matplotlib.cm as cm_mpl
+    import matplotlib.cm as _cm_mpl
     _has_matplotlib = True
     cmaps = {}
 except ModuleNotFoundError:
@@ -561,19 +561,14 @@ emoji = {
     r"\sigma": "\U000003C3",
 }
 
+
 # terminal color print
 def _has_colors(stream):
     if not hasattr(stream, "isatty"):
         return False
     if not stream.isatty():
         return False
-    try:
-        import curses
-        curses.setupterm()
-        return curses.tigetnum("colors") > 2
-    except:
-        return False
-#
+    return True
 _terminal_has_colors = _has_colors(sys.stdout)
 
 
@@ -781,7 +776,7 @@ def color_map(value, name="jet", vmin=None, vmax=None):
     if _has_matplotlib:
         # matplotlib is available, use it! ###########################
         if isinstance(name, str):
-            mp = cm_mpl.get_cmap(name=name)
+            mp = _cm_mpl.get_cmap(name=name)
         else:
             mp = name  # assume matplotlib.colors.LinearSegmentedColormap
         result = mp(values)[:, [0, 1, 2]]
@@ -1158,6 +1153,7 @@ def printc(
             sys.stdout.write(out + end)
 
     except:  # ------------------------------------------------------------- fallback
+
         try:
             print(*strings, end=end)
         except UnicodeEncodeError as e:
