@@ -1,10 +1,17 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 import numpy as np
-import vtk
+
+try:
+    import vedo.vtkclasses as vtk
+except ImportError:
+    import vtkmodules.all as vtk
+
 import vedo
 from vedo.colors import printc
 from vedo import utils
 from vedo import shapes
-from vedo.io import download, exportWindow, load, screenshot, Video
+from vedo.io import download, export_window, load, screenshot, Video
 from vedo.mesh import Mesh
 from vedo.plotter import Plotter
 from vedo.plotter import show
@@ -44,7 +51,7 @@ __all__ = [
     "Text2D",
     "screenshot",
     "Video",
-    "exportWindow",
+    "export_window",
 ]
 
 
@@ -55,7 +62,7 @@ def _inputsort(obj):
 
     u = None
     mesh = None
-    if not utils.isSequence(obj):
+    if not utils.is_sequence(obj):
         obj = [obj]
 
     for ob in obj:
@@ -111,7 +118,7 @@ def _compute_uvalues(u, mesh):
     # to have a scalar (or vector) for each point of the mesh
 
     if not u:
-        return
+        return np.array([])
     #    print('u',u)
 
     if hasattr(u, "compute_vertex_values"):  # old dolfin, works fine
@@ -250,8 +257,8 @@ def plot(*inputobj, **options):
         - tol, (float) - tolerance to reduce the number of seed points used in mesh
         - lw, (float) - line width of the streamline
         - direction, (str) - direction of integration ('forward', 'backward' or 'both')
-        - maxPropagation, (float) - max propagation of the streamline
-        - scalarRange, (list) - scalar range of coloring
+        - max_propagation, (float) - max propagation of the streamline
+        - scalar_range, (list) - scalar range of coloring
 
 
     warpZfactor : float
@@ -352,7 +359,7 @@ def plot(*inputobj, **options):
         - `pos`, `(list)`,
             the position of the camera in world coordinates
 
-        - `focalPoint`, `(list)`,
+        - `focal_point`, `(list)`,
             the focal point of the camera in world coordinates
 
         - `viewup`, `(list)`,
@@ -388,7 +395,7 @@ def plot(*inputobj, **options):
     """
     if len(inputobj) == 0:
         vedo.plotter_instance.interactive()
-        return
+        return None
 
     if "numpy" in str(type(inputobj[0])):
         from vedo.pyplot import plot as pyplot_plot
@@ -457,9 +464,9 @@ def plot(*inputobj, **options):
         axes = options.pop("axes", None)
         if axes is None:
             options["axes"] = {
-                "xyGrid": False,
-                "yzGrid": False,
-                "zxGrid": False,
+                "xygrid": False,
+                "yzgrid": False,
+                "zxgrid": False,
             }
         else:
             options["axes"] = axes  # put back
@@ -474,9 +481,9 @@ def plot(*inputobj, **options):
         axes = options.pop("axes", None)
         if axes is None:
             options["axes"] = {
-                "xyGrid": False,
-                "yzGrid": False,
-                "zxGrid": False,
+                "xygrid": False,
+                "yzgrid": False,
+                "zxgrid": False,
             }
         else:
             options["axes"] = axes  # put back
@@ -513,9 +520,9 @@ def plot(*inputobj, **options):
         axes = options.pop("axes", None)
         if axes is None:
             options["axes"] = {
-                "xyGrid": False,
-                "yzGrid": False,
-                "zxGrid": False,
+                "xygrid": False,
+                "yzgrid": False,
+                "zxgrid": False,
             }
         else:
             options["axes"] = axes  # put back
@@ -527,9 +534,6 @@ def plot(*inputobj, **options):
     if vedo.plotter_instance:
         if add:
             actors = vedo.plotter_instance.actors
-        elif at == 0:  # just remove scalarbars
-            for sb in vedo.plotter_instance.scalarbars:
-                vedo.plotter_instance.renderer.RemoveActor(sb)
 
     if mesh and ("mesh" in mode or "color" in mode or "displace" in mode):
 
@@ -546,12 +550,12 @@ def plot(*inputobj, **options):
         if c:
             actor.color(c)
         if lc:
-            actor.lineColor(lc)
+            actor.linecolor(lc)
         if alpha:
             alpha = min(alpha, 1)
             actor.alpha(alpha * alpha)
         if lw:
-            actor.lineWidth(lw)
+            actor.linewidth(lw)
             if wire and alpha:
                 lw1 = min(lw, 1)
                 actor.alpha(alpha * lw1)
@@ -591,11 +595,11 @@ def plot(*inputobj, **options):
 
         if scbar and c is None:
             if "3d" in scbar:
-                actor.addScalarBar3D()
+                actor.add_scalarbar3d()
             elif "h" in scbar:
-                actor.addScalarBar(horizontal=True)
+                actor.add_scalarbar(horizontal=True)
             else:
-                actor.addScalarBar(horizontal=False)
+                actor.add_scalarbar(horizontal=False)
 
         if len(isolns) > 0:
             ison = isolns.pop("n", 10)
@@ -609,7 +613,7 @@ def plot(*inputobj, **options):
             if isoz is not None:  # kind of hack to make isolines visible on flat meshes
                 d = isoz
             else:
-                d = actor.diagonalSize() / 400
+                d = actor.diagonal_size() / 400
             isos.z(actor.z() + d)
             actors.append(isos)
 
@@ -661,7 +665,7 @@ def plot(*inputobj, **options):
     # if vedo.plotter_instance:
     #     for a2 in vedo.collectable_actors:
     #         if isinstance(a2, vtk.vtkCornerAnnotation):
-    #             if 0 in a2.renderedAt: # remove old message
+    #             if 0 in a2.rendered_at: # remove old message
     #                 vedo.plotter_instance.remove(a2)
     #                 break
 
@@ -684,7 +688,7 @@ class MeshActor(Mesh):
         alpha = options.pop("alpha", 1)
         exterior = options.pop("exterior", False)
         fast = options.pop("fast", False)
-        computeNormals = options.pop("computeNormals", False)
+        compute_normals = options.pop("compute_normals", False)
 
         mesh, u = _inputsort(inputobj)
         if not mesh:
@@ -710,14 +714,13 @@ class MeshActor(Mesh):
             c=c,
             alpha=alpha,
         )
-        if computeNormals:
-            self.computeNormals()
+        if compute_normals:
+            self.compute_normals()
 
         self.mesh = mesh  # holds a dolfin Mesh obj
         self.u = u  # holds a dolfin function_data
         # holds the actual values of u on the mesh
         self.u_values = _compute_uvalues(u, mesh)
-        # self.addPointArray(self.u_values, "u_values")
 
     def move(self, u=None, deltas=None):
         """Move mesh according to solution `u` or from calculated vertex displacements `deltas`."""
@@ -783,14 +786,15 @@ def MeshPoints(*inputobj, **options):
                 dispsizes = utils.mag(u_values)
         else:  # u_values is 1D
             dispsizes = u_values
-        actor.addPointArray(dispsizes, "u_values")
+        actor.pointdata["u_values"] = dispsizes
+        actor.pointdata.select("u_values")
     return actor
 
 
 def MeshLines(*inputobj, **options):
     """
-    Build the line segments between two lists of points `startPoints` and `endPoints`.
-    `startPoints` can be also passed in the form ``[[point1, point2], ...]``.
+    Build the line segments between two lists of points `start_points` and `end_points`.
+    `start_points` can be also passed in the form ``[[point1, point2], ...]``.
 
     A dolfin ``Mesh`` that was deformed/modified by a function can be
     passed together as inputs.
@@ -807,22 +811,22 @@ def MeshLines(*inputobj, **options):
         return None
 
     if hasattr(mesh, "coordinates"):
-        startPoints = mesh.coordinates()
+        start_points = mesh.coordinates()
     else:
-        startPoints = mesh.geometry.points
+        start_points = mesh.geometry.points
 
     u_values = _compute_uvalues(u, mesh)
-    if not utils.isSequence(u_values[0]):
+    if not utils.is_sequence(u_values[0]):
         vedo.logger.error("cannot show Lines for 1D scalar values")
         raise RuntimeError()
 
-    endPoints = startPoints + u_values
+    end_points = start_points + u_values
     if u_values.shape[1] == 2:  # u_values is 2D
         u_values = np.insert(u_values, 2, 0, axis=1)  # make it 3d
-        startPoints = np.insert(startPoints, 2, 0, axis=1)  # make it 3d
-        endPoints = np.insert(endPoints, 2, 0, axis=1)  # make it 3d
+        start_points = np.insert(start_points, 2, 0, axis=1)  # make it 3d
+        end_points = np.insert(end_points, 2, 0, axis=1)  # make it 3d
 
-    actor = shapes.Lines(startPoints, endPoints, scale=scale, lw=lw, c=c, alpha=alpha)
+    actor = shapes.Lines(start_points, end_points, scale=scale, lw=lw, c=c, alpha=alpha)
 
     actor.mesh = mesh
     actor.u = u
@@ -843,22 +847,22 @@ def MeshArrows(*inputobj, **options):
         return None
 
     if hasattr(mesh, "coordinates"):
-        startPoints = mesh.coordinates()
+        start_points = mesh.coordinates()
     else:
-        startPoints = mesh.geometry.points
+        start_points = mesh.geometry.points
 
     u_values = _compute_uvalues(u, mesh)
-    if not utils.isSequence(u_values[0]):
+    if not utils.is_sequence(u_values[0]):
         vedo.logger.error("cannot show Arrows for 1D scalar values")
         raise RuntimeError()
 
-    endPoints = startPoints + u_values * scale
+    end_points = start_points + u_values * scale
     if u_values.shape[1] == 2:  # u_values is 2D
         u_values = np.insert(u_values, 2, 0, axis=1)  # make it 3d
-        startPoints = np.insert(startPoints, 2, 0, axis=1)  # make it 3d
-        endPoints = np.insert(endPoints, 2, 0, axis=1)  # make it 3d
+        start_points = np.insert(start_points, 2, 0, axis=1)  # make it 3d
+        end_points = np.insert(end_points, 2, 0, axis=1)  # make it 3d
 
-    actor = shapes.Arrows(startPoints, endPoints, s=s, alpha=alpha, res=res)
+    actor = shapes.Arrows(start_points, end_points, s=s, alpha=alpha, res=res)
     actor.color(c)
     actor.mesh = mesh
     actor.u = u
@@ -875,8 +879,8 @@ def MeshStreamLines(*inputobj, **options):
     tol = options.pop("tol", 0.02)
     lw = options.pop("lw", 2)
     direction = options.pop("direction", "forward")
-    maxPropagation = options.pop("maxPropagation", None)
-    scalarRange = options.pop("scalarRange", None)
+    max_propagation = options.pop("max_propagation", None)
+    scalar_range = options.pop("scalar_range", None)
     probes = options.pop("probes", None)
 
     tubes = options.pop("tubes", {})  # todo
@@ -888,16 +892,17 @@ def MeshStreamLines(*inputobj, **options):
         return None
 
     u_values = _compute_uvalues(u, mesh)
-    if not utils.isSequence(u_values[0]):
+    if not utils.is_sequence(u_values[0]):
         vedo.logger.error("cannot show Arrows for 1D scalar values")
         raise RuntimeError()
     if u_values.shape[1] == 2:  # u_values is 2D
         u_values = np.insert(u_values, 2, 0, axis=1)  # make it 3d
 
     meshact = MeshActor(u)
-    meshact.addPointArray(u_values, "u_values")
+    meshact.pointdata["u_values"] = u_values
+    meshact.pointdata.select("u_values")
 
-    if utils.isSequence(probes):
+    if utils.is_sequence(probes):
         pass  # it's already it
     elif tol:
         print("decimating mesh points to use them as seeds...")
@@ -918,10 +923,10 @@ def MeshStreamLines(*inputobj, **options):
         meshact,
         probes,
         direction=direction,
-        maxPropagation=maxPropagation,
+        max_propagation=max_propagation,
         tubes=tubes,
-        scalarRange=scalarRange,
-        activeVectors="u_values",
+        scalar_range=scalar_range,
+        active_vectors="u_values",
     )
 
     if lw:
