@@ -1,4 +1,11 @@
-import vtk
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+try:
+    import vedo.vtkclasses as vtk
+except ImportError:
+    import vtkmodules.all as vtk
+
 import vedo
 from vedo import utils
 from vedo.base import BaseGrid
@@ -11,14 +18,14 @@ Work with tetrahedral meshes
 .. image:: https://vedo.embl.es/images/volumetric/82767107-2631d500-9e25-11ea-967c-42558f98f721.jpg
 """
 
-__all__ = ["TetMesh", "delaunay3D"]
+__all__ = ["TetMesh", "delaunay3d"]
 
 
 ##########################################################################
-def delaunay3D(mesh, alphaPar=0, tol=None, boundary=False):
+def delaunay3d(mesh, alpha_parameter=0, tol=None, boundary=False):
     """Create 3D Delaunay triangulation of input points."""
     deln = vtk.vtkDelaunay3D()
-    if utils.isSequence(mesh):
+    if utils.is_sequence(mesh):
         pd = vtk.vtkPolyData()
         vpts = vtk.vtkPoints()
         vpts.SetData(utils.numpy2vtk(mesh, dtype=float))
@@ -26,7 +33,7 @@ def delaunay3D(mesh, alphaPar=0, tol=None, boundary=False):
         deln.SetInputData(pd)
     else:
         deln.SetInputData(mesh.GetMapper().GetInput())
-    deln.SetAlpha(alphaPar)
+    deln.SetAlpha(alpha_parameter)
     deln.AlphaTetsOn()
     deln.AlphaTrisOff()
     deln.AlphaLinesOff()
@@ -44,13 +51,13 @@ def _buildtetugrid(points, cells):
 
     if len(points) == 0:
         return ug
-    if not utils.isSequence(points[0]):
+    if not utils.is_sequence(points[0]):
         return ug
 
     if len(cells) == 0:
         return ug
 
-    if not utils.isSequence(cells[0]):
+    if not utils.is_sequence(cells[0]):
         tets = []
         nf = cells[0] + 1
         for i, cl in enumerate(cells):
@@ -61,10 +68,10 @@ def _buildtetugrid(points, cells):
                 tets.append(cell)
         cells = tets
 
-    sourcePoints = vtk.vtkPoints()
+    source_points = vtk.vtkPoints()
     varr = utils.numpy2vtk(points, dtype=float)
-    sourcePoints.SetData(varr)
-    ug.SetPoints(sourcePoints)
+    source_points.SetData(varr)
+    ug.SetPoints(source_points)
 
     sourceTets = vtk.vtkCellArray()
     for f in cells:
@@ -129,7 +136,7 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
             tt.Update()
             self._data = tt.GetOutput()
 
-        elif utils.isSequence(inputobj):
+        elif utils.is_sequence(inputobj):
             # if "ndarray" not in inputtype:
             #     inputobj = np.array(inputobj)
             self._data = _buildtetugrid(inputobj[0], inputobj[1])
@@ -185,14 +192,14 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         cloned.name = self.name
         return cloned
 
-    def addQuality(self, measure=7):
+    def compute_quality(self, metric=7):
         """
         Calculate functions of quality for the elements of a triangular mesh.
         This method adds to the mesh a cell array named "Quality".
 
         Parameters
         ----------
-        measure : int
+        metric : int
             type of estimator
 
                 - EDGE RATIO, 0
@@ -212,10 +219,50 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         """
         qf = vtk.vtkMeshQuality()
         qf.SetInputData(self._data)
-        qf.SetTetQualityMeasure(measure)
+        qf.SetTetQualityMeasure(metric)
         qf.SaveCellQualityOn()
         qf.Update()
-        return self._update(qf.GetOutput())
+        self._update(qf.GetOutput())
+        return utils.vtk2numpy(qf.GetOutput().GetCellData().GetArray("Quality"))
+
+    def compute_tets_volume(self):
+        """Add to this mesh a cell data array containing the areas of the polygonal faces"""
+        csf = vtk.vtkCellSizeFilter()
+        csf.SetInputData(self._data)
+        csf.SetComputeArea(False)
+        csf.SetComputeVolume(True)
+        csf.SetComputeLength(False)
+        csf.SetComputeVertexCount(False)
+        csf.SetVolumeArrayName("TetVolume")
+        csf.Update()
+        self._update(csf.GetOutput())
+        return utils.vtk2numpy(csf.GetOutput().GetCellData().GetArray("TetVolume"))
+
+    def check_validity(self, tol=0):
+        """
+        Return an array of possible problematic tets following this convention:
+
+            Valid               =  0
+            WrongNumberOfPoints = 01
+            IntersectingEdges   = 02
+            IntersectingFaces   = 04
+            NoncontiguousEdges  = 08
+            Nonconvex           = 10
+            OrientedIncorrectly = 20
+
+        Parameters
+        ----------
+        tol : float
+            This value is used as an epsilon for floating point
+            equality checks throughout the cell checking process.
+        """
+        vald = vtk.vtkCellValidator()
+        if tol:
+            vald.SetTolerance(tol)
+        vald.SetInputData(self._data)
+        vald.Update()
+        varr = vald.GetOutput().GetCellData().GetArray("ValidityState")
+        return utils.vtk2numpy(varr)
 
     def threshold(self, name=None, above=None, below=None, on="cells"):
         """
@@ -265,7 +312,7 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         th.Update()
         return self._update(th.GetOutput())
 
-    def decimate(self, scalarsName, fraction=0.5, N=None):
+    def decimate(self, scalars_name, fraction=0.5, N=None):
         """
         Downsample the number of tets in a TetMesh to a specified fraction.
 
@@ -281,7 +328,7 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         """
         decimate = vtk.vtkUnstructuredGridQuadricDecimation()
         decimate.SetInputData(self._data)
-        decimate.SetScalarsName(scalarsName)
+        decimate.SetScalarsName(scalars_name)
 
         if N:  # N = desired number of points
             decimate.SetNumberOfTetsOutput(N)
@@ -300,29 +347,29 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         sd.Update()
         return self._update(sd.GetOutput())
 
-    def isosurface(self, threshold=True):
+    def isosurface(self, value=True):
         """
         Return a ``Mesh`` isosurface.
 
-        Set `threshold` to a single value or list of values to compute the isosurface(s)
+        Set `value` to a single value or list of values to compute the isosurface(s)
         """
         if not self._data.GetPointData().GetScalars():
-            self.mapCellsToPoints()
+            self.map_cells_to_points()
         scrange = self._data.GetPointData().GetScalars().GetRange()
         cf = vtk.vtkContourFilter()  # vtk.vtkContourGrid()
         cf.SetInputData(self._data)
 
-        if utils.isSequence(threshold):
-            cf.SetNumberOfContours(len(threshold))
-            for i, t in enumerate(threshold):
+        if utils.is_sequence(value):
+            cf.SetNumberOfContours(len(value))
+            for i, t in enumerate(value):
                 cf.SetValue(i, t)
             cf.Update()
         else:
-            if threshold is True:
-                threshold = (2 * scrange[0] + scrange[1]) / 3.0
-                # print('automatic threshold set to ' + utils.precision(threshold, 3), end=' ')
+            if value is True:
+                value = (2 * scrange[0] + scrange[1]) / 3.0
+                # print('automatic value set to ' + utils.precision(value, 3), end=' ')
                 # print('in [' + utils.precision(scrange[0], 3) + ', ' + utils.precision(scrange[1], 3)+']')
-            cf.SetValue(0, threshold)
+            cf.SetValue(0, value)
             cf.Update()
 
         clp = vtk.vtkCleanPolyData()
